@@ -3,24 +3,30 @@ use warnings;
 use Data::Dump;
 use lib '../lib', '../blib/arch', '../blib/lib';
 use Dyn qw[:dcb];
-use Data::Dump;
-ddx \%Dyn::;
 $|++;
 #
 my $coderef = sub { warn 'Here'; return 88 };
+my $cb      = dcbNewCallback( 'ifsdl)s', $coderef, 5 );
 
-#my $cb = Dyn::Callback->new('ifsdl)s', $coderef, 5);
-my $cb = dcbNewCallback( 'ifsdl)s', $coderef, 5 );
+#my $cb = dcbNewCallback( 'i)s', $coderef, 5 );
 #
 warn $cb;
 #
 my $result = $cb->call( 12, 23.5, 3, 1.82, 9909 );    # Don't make these an array ref
+warn;
 #
 warn $result;
 
 #$cb->init();
+warn;
 {
-    my $cb = dcbNewCallback( 'i)v', $coderef, 5 );
+    my $cb = dcbNewCallback(
+        'i)v',
+        sub { warn 'Here!' }
+
+            #$coderef
+        , 5
+    );
     #
     warn $cb;
     #
