@@ -1,20 +1,22 @@
-package Dyn 0.02 {
+package Dyn 0.03 {
     use strict;
     use warnings;
+    no warnings 'redefine';
     use 5.030;
     use XSLoader;
-    XSLoader::load( __PACKAGE__, $Dyn::VERSION );
+    XSLoader::load( __PACKAGE__, our $VERSION );
     #
     use Dyn::Call qw[:all];
     use Dyn::Callback qw[:all];
     use Dyn::Load qw[:all];
+    use experimental 'signatures';
     #
     use parent 'Exporter';
     our %EXPORT_TAGS = (
         dc    => [@Dyn::Call::EXPORT_OK],
         dcb   => [@Dyn::Callback::EXPORT_OK],
         dl    => [@Dyn::Load::EXPORT_OK],
-        sugar => [qw[call]]
+        sugar => [qw[call load MODIFY_SCALAR_ATTRIBUTES MODIFY_CODE_ATTRIBUTES AUTOLOAD]]
     );
     @{ $EXPORT_TAGS{all} } = our @EXPORT_OK = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
 };
@@ -29,15 +31,15 @@ Dyn - dyncall Backed FFI
 
 =head1 SYNOPSIS
 
-    use Dyn qw[:dl];                                       # Exports nothing by default
-    my $lib = dlLoadLibrary('/usr/lib/libm-2.33.so');      # or a .dll on Windows or .dylib on macOS
-    my $exp = Dyn::call( $lib, 'pow', 'dd)d', 2.0, 10.0 ); # 1024
+    use Dyn qw[:sugar];	# Exports nothing by default
+    sub pow : Dyn( '/usr/lib/libm-2.33.so', '(dd)d');
+    print pow( 2, 10 );	# 1024
 
 =head1 DESCRIPTION
 
 Dyn is a wrapper around L<dyncall|https://dyncall.org/>.
 
-Dyn includes...
+This distribution includes...
 
 =over
 
@@ -63,30 +65,70 @@ Functions can be imported with the C<:dl> tag.
 
 =back
 
+Honestly, you should be using one of the above packages rather than this one as
+they provide clean wrappers of dyncall's C functions. This package contains the
+sugary API.
+
 =head1 Functions
 
 While most of the upstream API is covered in the L<Dyn::Call>,
 L<Dyn::Callback>, and L<Dyn::Load> packages, all the sugar is right here in
-C<Dyn>. All of these methods may be imported by name or with the C<:sugar> tag.
+C<Dyn>. The most simple use of C<Dyn> would look something like this:
+
+	use Dyn ':sugar';
+	sub some_argless_function() : Dyn('somelib.so', '()v');
+	some_argless_function();
+
+Be aware that this will look a lot more like L<NativeCall from
+Raku|https://docs.raku.org/language/nativecall> before v1.0!
+
+The second line above looks like a normal Perl sub declaration but includes the
+C<:Dyn> attribute to specify that the sub is actually defined in a native
+library.
+
+To avoid banging your head on a built-in function, you may name your sub
+anything else and let Dyn know what symbol to attach:
+
+	sub my_abs : Dyn('my_lib.dll', '(d)d', 'abs');
+	CORE::say my_abs( -75 ); # Should print 75 if your abs is something that makes sense
+
+This is by far the fastest way to work with this distribution but it's not by
+any means the only way.
+
+All of the following methods may be imported by name or with the C<:sugar> tag.
 
 Note that everything here is subject to change before v1.0.
 
-=head2 C<call( ... )>
+=head2 C<load( ... )>
 
-Invokes the function according to the provided L<signature|/Signatures>.
+Creates a wrapper around a given symbol in a given library.
 
-    my $value = call( dlLoadLibrary($path), 'pow', 'dd)d', 2.0, 10.0 );
+	my $pow = Dyn::load( 'C:\Windows\System32\user32.dll', 'pow', 'dd)d' );
 
 Expected parameters include:
 
 =over
 
-=item C<libhandle> - pointer returned by L<< C<dlLoadLibrary( ... )>|Dyn::Load/C<dlLoadLibrary( ... )> >>
+=item C<lib> - pointer returned by L<< C<dlLoadLibrary( ... )>|Dyn::Load/C<dlLoadLibrary( ... )> >> or the path of the library as a string
 
 =item C<name> - the name of the symbol to call
 
 =item C<signature> - signature defining argument types, return type, and optionally the calling convention used
 
+=back
+
+=head2 C<call( ... )>
+
+Invokes the function according to the provided L<signature|/Signatures>.
+
+	my $value = $pow->call( 2.0, 10 ); # Same as Dyn::call( $pow, 2.0, 10 )
+
+Expected parameters include:
+
+=over
+
+=item C<bind> - C<Dyn> object bound with C<load( ... )>
+
 =item C<...> - any arguments to bind to the call
 
 =back
